@@ -1017,7 +1017,7 @@ class RemoteJob(object):
                 if self._remove[series]['points'] and self._remove[series]['fields']:
                     remove = 'all'
                 elif self._remove[series]['points']:
-                    remove = 'series'
+                    remove = 'points'
                 else:
                     remove = 'fields'
                 values['keep_only'] = remove
